package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.dto.CouponDTO;
import com.chelvc.cloud.vehicle.client.param.CouponModifyParam;
import com.chelvc.cloud.vehicle.client.param.CouponPagingParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 优惠券业务接口
 *
 * @author qizai
 * @date 2023/9/8
 */
@FeignClient("vehicle")
public interface CouponClient {
    /**
     * 新增优惠券
     *
     * @param param 新增参数
     * @return 优惠券主键
     */
    @PostMapping("/coupon/addCoupon")
    Long addCoupon(@RequestBody CouponModifyParam param);

    /**
     * 修改优惠券
     *
     * @param id    优惠券主键
     * @param param 修改参数
     */
    @PutMapping("/coupon/updateCoupon")
    void updateCoupon(@RequestParam("id") Long id, @RequestBody CouponModifyParam param);

    /**
     * 删除商品优惠券
     *
     * @param id 商品优惠券主键
     */
    @DeleteMapping("/coupon")
    void deleteCoupon(@RequestParam("id") Long id);

    /**
     * 获取优惠券信息
     *
     * @param id 优惠券主键
     * @return 优惠券信息
     */
    @GetMapping("/coupon/getCoupon")
    CouponDTO getCoupon(@RequestParam("id") Long id);

    /**
     * 查询优惠券信息
     *
     * @param param 查询参数
     * @return 优惠券分页信息
     */
    @GetMapping("/coupon/getCouponPaging")
    Pagination<CouponDTO> getCouponPaging(@SpringQueryMap CouponPagingParam param);

    /**
     * 查询优惠券信息
     *
     * @param merchantId 商家ID
     * @param param      分页参数
     * @return 优惠券分页信息
     */
    @GetMapping("/coupon/getMerchantCouponPaging")
    Pagination<CouponDTO> getMerchantCouponPaging(@RequestParam("merchantId") Long merchantId,
                                                  @SpringQueryMap CouponPagingParam param);
}
