package com.chelvc.cloud.vehicle.client;

import java.util.List;

import com.chelvc.cloud.vehicle.client.constant.ReserveStatus;
import com.chelvc.cloud.vehicle.client.dto.MerchantReservationDTO;
import com.chelvc.cloud.vehicle.client.dto.ReservationDTO;
import com.chelvc.cloud.vehicle.client.dto.UserReservationDTO;
import com.chelvc.cloud.vehicle.client.param.ReservationModifyParam;
import com.chelvc.cloud.vehicle.client.param.ReservationPagingParam;
import com.chelvc.cloud.vehicle.client.param.ReservationQueryParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 预约业务接口
 *
 * @author Woody
 * @date 2023/7/17
 */
@FeignClient("vehicle")
public interface ReservationClient {
    /**
     * 新增预约信息
     *
     * @param merchantId 商家ID
     * @param param      预约参数
     */
    @PostMapping("/reservation/addReservation")
    void addReservation(@RequestParam("merchantId") Long merchantId, @RequestBody ReservationModifyParam param);

    /**
     * 查询用户预约列表
     *
     * @param param 查询参数
     * @return 用户预约列表
     */
    @GetMapping("/reservation/listUserReservations")
    List<ReservationDTO> listUserReservations(@SpringQueryMap ReservationQueryParam param);

    /**
     * 取消预约
     *
     * @param id 预约记录逐渐主键
     */
    @DeleteMapping("/reservation")
    void deleteReservation(@RequestParam("id") Long id);

    /**
     * 查询预约
     *
     * @param param 查询参数
     * @return 预约分页信息
     */
    @GetMapping("/reservation/getReservationPaging")
    Pagination<ReservationDTO> getReservationPaging(@SpringQueryMap ReservationPagingParam param);

    /**
     * 查询商家被预约列表
     *
     * @param param 查询参数
     * @return 用户预约列表
     */
    @GetMapping("/reservation/listMerchantReservations")
    List<ReservationDTO> listMerchantReservations(@SpringQueryMap ReservationQueryParam param);

    /**
     * 更新预约单的状态
     *
     * @param id     预约单ID
     * @param status 预约单的状态
     */
    @PutMapping("/reservation/updateReservationsStatus")
    void updateReservationsStatus(@RequestParam("id") Long id, @RequestParam("status") ReserveStatus status);


    /**
     * 预约详情
     *
     * @param id
     * @return
     */
    @GetMapping("/reservation/getDetail")
    ReservationDTO getDetail(@RequestParam("id") Long id);


    /**
     * 商家端分页查询预约
     *
     * @param param 查询参数
     * @return 预约分页信息
     */
    @GetMapping("/reservation/getMerchantList")
    Pagination<MerchantReservationDTO> getMerchantReservationPaging(@SpringQueryMap ReservationPagingParam param);


    /**
     * 用户端分页查询预约
     *
     * @param param 查询参数
     * @return 预约分页信息
     */
    @GetMapping("/reservation/getUserReservation")
    Pagination<UserReservationDTO> getUserReservationPaging(@SpringQueryMap ReservationPagingParam param);
}
