package com.chelvc.cloud.vehicle.server.controller;

import com.chelvc.cloud.vehicle.client.dto.CouponDTO;
import com.chelvc.cloud.vehicle.client.param.CouponModifyParam;
import com.chelvc.cloud.vehicle.client.param.CouponPagingParam;
import com.chelvc.cloud.vehicle.server.service.CouponService;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 优惠券业务接口
 *
 * @author qizai
 * @date 2023/9/8
 */
@RestController
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class CouponController {

    private final CouponService couponService;

    /**
     * 新增优惠券
     *
     * @param param 新增参数
     * @return 优惠券主键
     */
    @PostMapping("/coupon/addCoupon")
    public Long addCoupon(@RequestBody CouponModifyParam param) {
        return couponService.addCoupon(param);
    }

    /**
     * 修改优惠券
     *
     * @param id    优惠券主键
     * @param param 修改参数
     */
    @PutMapping("/coupon/updateCoupon")
    public void updateCoupon(@RequestParam("id") Long id, @RequestBody CouponModifyParam param) {
        couponService.updateCoupon(id, param);
    }

    /**
     * 删除商品优惠券
     *
     * @param id 商品优惠券主键
     */
    @DeleteMapping("/coupon")
    public void deleteCoupon(@RequestParam("id") Long id) {
        couponService.deleteCoupon(id);
    }

    /**
     * 获取优惠券信息
     *
     * @param id 优惠券主键
     * @return 优惠券信息
     */
    @GetMapping("/coupon/getCoupon")
    public CouponDTO getCoupon(@RequestParam("id") Long id) {
        return couponService.getCoupon(id);
    }

    /**
     * 查询优惠券信息
     *
     * @param param 查询参数
     * @return 优惠券分页信息
     */
    @GetMapping("/coupon/getCouponPaging")
    public Pagination<CouponDTO> getCouponPaging(@SpringQueryMap CouponPagingParam param) {
        return couponService.getCouponPaging(param);
    }

    /**
     * 查询优惠券信息
     *
     * @param merchantId 商家ID
     * @param param      分页参数
     * @return 优惠券分页信息
     */
    @GetMapping("/coupon/getMerchantCouponPaging")
    public Pagination<CouponDTO> getMerchantCouponPaging(@RequestParam("merchantId") Long merchantId,
                                                         @SpringQueryMap CouponPagingParam param) {
        return couponService.getMerchantCouponPaging(merchantId, param);
    }
}
