package com.chelvc.cloud.vehicle.server.controller;

import java.util.List;

import com.chelvc.cloud.vehicle.client.dto.FeedBackDTO;
import com.chelvc.cloud.vehicle.client.param.FeedBackModifyParam;
import com.chelvc.cloud.vehicle.client.param.FeedBackPagingParam;
import com.chelvc.cloud.vehicle.server.service.FeedbackService;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 意见反馈接口
 *
 * @author liude
 * @data 2024/1/12
 */
@RestController
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class FeedbackController {

    private final FeedbackService feedbackService;

    /**
     * 新增意见反馈
     *
     * @param param 新增参数
     * @return 主键
     */
    @PostMapping("/feedback/addFeedback")
    public Long addFeedback(@RequestBody FeedBackModifyParam param) {
        return feedbackService.addFeedback(param);
    }

    /**
     * 修改意见反馈
     *
     * @param id    主键
     * @param param 修改参数
     */
    @PutMapping("/feedback/updateFeedback")
    public void updateFeedback(@RequestParam("id") Long id, @RequestBody FeedBackModifyParam param) {
        feedbackService.updateFeedback(id, param);
    }

    /**
     * 获取意见反馈信息
     *
     * @return
     */
    @GetMapping("/feedback/getFeedback")
    public List<FeedBackDTO> getFeedback(@RequestParam("channel") String channel) {
        return feedbackService.getFeedback(channel);
    }

    /**
     * 意见反馈分页查询
     *
     * @param param
     * @return
     */
    @GetMapping("/feedback/getFeedbackPaging")
    public Pagination<FeedBackDTO> getFeedbackPaging(FeedBackPagingParam param) {
        return feedbackService.getFeedbackPaging(param);
    }

    /**
     * 更新意见反馈状态
     *
     * @param id
     * @param status
     */
    @PutMapping("/feedback/updateStatus")
    public void updateStatus(@RequestParam("id") Long id, @RequestParam("status") String status) {
        feedbackService.updateStatus(id, status);
    }
}
