package com.chelvc.cloud.vehicle.server.controller;

import java.util.List;

import com.chelvc.cloud.vehicle.client.dto.HelpDTO;
import com.chelvc.cloud.vehicle.client.param.HelpModifyParam;
import com.chelvc.cloud.vehicle.client.param.HelpPagingParam;
import com.chelvc.cloud.vehicle.server.service.HelpService;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 帮助Service接口
 *
 * @author liude
 * @date 2023-11-08
 */
@RestController
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class HelpController {
    private final HelpService helpService;

    /**
     * 查询帮助
     *
     * @param id 帮助主键
     * @return 帮助
     */
    @GetMapping("/help/selectHelpById")
    public HelpDTO selectHelpById(@RequestParam("id") Long id) {
        return helpService.selectHelpById(id);
    }

    /**
     * 查询帮助列表
     *
     * @param param 帮助
     * @return 帮助集合
     */
    @GetMapping("/help/selectHelpList")
    public List<HelpDTO> selectHelpList(@SpringQueryMap HelpModifyParam param) {
        return helpService.selectHelpList(param);
    }

    /**
     * 新增帮助
     *
     * @param param 帮助
     * @return 结果
     */
    @PostMapping("/help/insertHelp")
    public void insertHelp(@RequestBody HelpModifyParam param) {
        helpService.insertHelp(param);
    }

    /**
     * 修改帮助
     *
     * @param param 帮助
     * @return 结果
     */
    @PutMapping("/help/updateHelp")
    public void updateHelp(@RequestParam("id") Long id, @RequestBody HelpModifyParam param) {
        helpService.updateHelp(id, param);
    }


    /**
     * 删除帮助信息
     *
     * @param id 帮助主键
     * @return 结果
     */
    @DeleteMapping("/help")
    public void deleteHelpById(@RequestParam("id") Long id) {
        helpService.deleteHelpById(id);
    }

    /**
     * 分页查询帮助列表
     *
     * @param param
     * @return
     */
    @GetMapping("/help/getHelpPaging")
    public Pagination<HelpDTO> getHelpPaging(HelpPagingParam param) {
        return helpService.getHelpPaging(param);
    }
}
