package com.chelvc.cloud.vehicle.server.controller;

import com.chelvc.cloud.vehicle.client.constant.SystemInformType;
import com.chelvc.cloud.vehicle.client.dto.*;
import com.chelvc.cloud.vehicle.server.service.InformService;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.common.model.Paging;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class InformController {

    private final InformService informService;

    /**
     * 获取用户的订单通知列表
     *
     * @param paging 分页信息
     * @return 用户的订单列表
     */
    @GetMapping("/inform/selectOmsOrderOperateHistoryListByUserId")
    public Pagination<OmsOrderOperateHistoryDTO> selectOmsOrderOperateHistoryListByUserId(
            @RequestParam("userId") Long userId,
            @RequestParam("paging") Paging paging) {
        return informService.selectOmsOrderOperateHistoryListByUserId(userId, paging);
    }

    /**
     * 将新系统通知标识未读改为已读
     */
    @GetMapping("/inform/changeSystemInformFlag")
    public void changeSystemInformFlag(@RequestParam("type") SystemInformType type,
                                       @RequestParam("userId") Long userId) {
        informService.changeSystemInformFlag(type, userId);
    }

    /**
     * 查看是否有系统新消息
     */
    @GetMapping("/inform/getNewInform")
    public NewInformDTO getNewInform(@RequestParam("userId") Long userId) {
        return informService.getNewInform(userId);
    }

    /**
     * (商家端)查看是否有系统新消息
     */
    @GetMapping("/inform/getMerchantNewInform")
    public NewMerchantInformDTO getMerchantNewInform(@RequestParam("merchantId") Long merchantId) {
        return informService.getMerchantNewInform(merchantId);
    }

    /**
     * (商家端)获取订单退款申请列表
     *
     * @param paging 分页信息
     * @return 用户的订单通知列表
     */
    @GetMapping("/inform/listOrderReturnApply")
    public Pagination<OmsOrderReturnApplyIdsDTO> listOrderReturnApply(@RequestParam("merchantId") Long merchantId,
                                                                      @RequestParam("paging") Paging paging) {
        return informService.listOrderReturnApply(merchantId, paging);
    }

    /**
     * 获取用户的支付通知列表
     *
     * @param paging 分页信息
     * @return 用户的订单通知列表
     */
    @GetMapping("/inform/selectOmsOrderPayHistoryListByUserId")
    public Pagination<OmsOrderDTO> selectOmsOrderPayHistoryListByUserId(@RequestParam("userId") Long userId,
                                                                        @RequestParam("paging") Paging paging) {
        return informService.selectOmsOrderPayHistoryListByUserId(userId, paging);
    }

    /**
     * 取用户的点赞回复通知列表
     *
     * @param paging 分页信息
     * @return 用户的订单通知列表
     */
    @GetMapping("/inform/selectEvaluateListByUserId")
    public Pagination<EvaluateDTO> selectEvaluateListByUserId(@RequestParam("userId") Long userId,
                                                              @RequestParam("paging") Paging paging) {
        return informService.selectEvaluateListByUserId(userId, paging);
    }

    /**
     * 取用户的评价通知列表
     *
     * @param paging 分页信息
     * @return 用户的评价通知列表
     */
    @GetMapping("/inform/selectCommentListByUserId")
    public Pagination<GoodsAssessDto> selectCommentListByUserId(@RequestParam("userId") Long userId,
                                                                @RequestParam("paging") Paging paging) {
        return informService.selectCommentListByUserId(userId, paging);
    }

    /**
     * 取用户的优惠券通知列表
     *
     * @param paging 分页信息
     * @return 用户的评价通知列表
     */
    @GetMapping("/inform/selectUserCouponListByUserId")
    public Pagination<UserCouponDTO> selectUserCouponListByUserId(@RequestParam("userId") Long userId,
                                                                  @RequestParam("paging") Paging paging) {
        return informService.selectUserCouponListByUserId(userId, paging);
    }
}
