package com.chelvc.cloud.vehicle.server.controller;


import java.util.List;

import com.chelvc.cloud.vehicle.client.dto.UserCouponDTO;
import com.chelvc.cloud.vehicle.client.param.UserCouponModifyParam;
import com.chelvc.cloud.vehicle.client.param.UserCouponPagingParam;
import com.chelvc.cloud.vehicle.client.param.UserCouponQueryParam;
import com.chelvc.cloud.vehicle.server.service.UserCouponService;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 优惠券领取记录业务接口
 *
 * @author 七仔
 * @date 2023/3/29 21:59
 */
@RestController
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class UserCouponController {

    private final UserCouponService userCouponService;

    /**
     * 查询用户优惠券
     *
     * @param param 查询参数
     * @return 用户优惠券信息列表
     */
    @GetMapping("/userCoupon/listUserCoupons")
    public List<UserCouponDTO> listUserCoupons(UserCouponQueryParam param) {
        return userCouponService.listUserCoupons(param);
    }

    /**
     * 获取当前用户对于当前商品可使用的优惠券列表
     *
     * @param param 查询参数
     * @return 用户可用优惠券信息列表
     */
    @GetMapping("/userCoupon/listUserCanUseCoupons")
    public List<UserCouponDTO> listUserCanUseCoupons(UserCouponQueryParam param) {
        return userCouponService.listUserCanUseCoupons(param);
    }

    /**
     * 新增优惠券领取记录
     *
     * @param param 新增参数
     * @return 优惠券领取记录主键
     */
    @PostMapping("/userCoupon/addUserCoupon")
    public Long addUserCoupon(@RequestBody UserCouponModifyParam param) {
        return userCouponService.addUserCoupon(param);
    }

    /**
     * 修改优惠券领取记录
     *
     * @param id    优惠券领取记录主键
     * @param param 修改参数
     */
    @PutMapping("/userCoupon/updateUserCoupon")
    public void updateUserCoupon(@RequestParam("id") Long id, @RequestBody UserCouponModifyParam param) {
        userCouponService.updateUserCoupon(id, param);
    }

    /**
     * 获取优惠券领取记录
     *
     * @param id 优惠券领取记录主键
     * @return 优惠券领取记录
     */
    @GetMapping("/userCoupon/getUserCoupon")
    public UserCouponDTO getUserCoupon(@RequestParam("id") Long id) {
        return userCouponService.getUserCoupon(id);
    }

    /**
     * 查询优惠券领取记录
     *
     * @param param 查询参数
     * @return 优惠券领取记录分页信息
     */
    @GetMapping("/userCoupon/getUserCouponPaging")
    public Pagination<UserCouponDTO> getUserCouponPaging(UserCouponPagingParam param) {
        return userCouponService.getUserCouponPaging(param);
    }

    /**
     * 领取优惠券
     *
     * @param couponId 优惠券ID
     * @return 优惠券领取记录主键
     */
    @PostMapping("/userCoupon/claimCoupon")
    public Long claimCoupon(@RequestParam("couponId") Long couponId) {
        return userCouponService.claimCoupon(couponId);
    }
}
