package com.chelvc.cloud.vehicle.server.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.vehicle.client.dto.BalanceDetailDTO;
import com.chelvc.cloud.vehicle.client.dto.WalletDTO;
import com.chelvc.cloud.vehicle.client.param.QueryMerchantBalanceParam;
import com.chelvc.cloud.vehicle.server.dao.BalanceDetailMapper;
import com.chelvc.cloud.vehicle.server.entity.BalanceDetail;
import com.chelvc.cloud.vehicle.server.service.BalanceDetailService;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;

@Service
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class BalanceDetailServiceImpl extends ServiceImpl<BalanceDetailMapper, BalanceDetail>
        implements BalanceDetailService{

    private final BalanceDetailMapper merchantBalanceDetailMapper;
    @Override
    public void recordFlow(Long orderId, Integer type, Long targetId, BigDecimal operateAmount, BigDecimal surplusAmount,
                           Integer flowType, Integer operateType, Long sourceId) {
        BalanceDetail detail = new BalanceDetail();
        detail.setType(type);
        detail.setFlowType(flowType);
        detail.setOperateType(operateType);
        detail.setOrderId(orderId);
        detail.setTargetId(targetId);
        detail.setCreateTime(LocalDateTime.now());
        detail.setOperateAmount(operateAmount);
        detail.setSurplusAmount(surplusAmount);
        detail.setSourceId(sourceId);
        baseMapper.insert(detail);
    }

    @Override
    public Pagination<BalanceDetailDTO> queryByMerchantId(QueryMerchantBalanceParam param,
                    Integer pageNum, Integer pageSize, Integer type) {
        Long merchantId = param.getMerchantId();
        if(merchantId == null){
            return null;
        }
        Page<BalanceDetailDTO> page = new Page<>(pageNum, pageSize);
        IPage<BalanceDetailDTO> result = merchantBalanceDetailMapper
                .queryByUserId(page, queryWrapper(param, merchantId, type));
        return Pagination.<BalanceDetailDTO>builder().total(result.getTotal()).pages(result.getPages())
                .records(result.getRecords()).build();
    }

    @Override
    public WalletDTO getMerchantAsset(Long merchantId) {
        LocalDate today = LocalDate.now(); // 获取今天的日期
        LocalDateTime midnight = LocalDateTime.of(today, LocalTime.MIDNIGHT); // 获取今天凌晨的时间
        LocalDate yesterday = today.minusDays(1);
        LocalDateTime yesterdayMidnight = LocalDateTime.of(yesterday, LocalTime.MIN);
        return merchantBalanceDetailMapper.getMerchantAsset(merchantId, midnight, yesterdayMidnight);
    }

    public QueryWrapper<BalanceDetail> queryWrapper(QueryMerchantBalanceParam param, Long merchantId, Integer type) {
        QueryWrapper<BalanceDetail> lqw = Wrappers.query();
        lqw.eq("t1.type", type);
        lqw.eq("t1.target_id", merchantId);
        if(param.getFlowType() != null){
            lqw.eq("t1.flow_type", param.getFlowType());
        }
        if(param.getOperateType() != null){
            lqw.eq("t1.operate_type", param.getOperateType());
        }
        if(param.getStartTime() != null){
            lqw.ge("t1.create_time", param.getStartTime());
        }
        if(param.getEndTime() != null){
            lqw.lt("t1.create_time", param.getEndTime());
        }
        lqw.orderByDesc("t1.create_time");
        return lqw;
    }
}
